@@ -61,7 +61,7 @@ QT_BEGIN_NAMESPACE
     \ingroup qtquick-animation-properties
     \since 5.0
     \inherits Animation
-    \brief Animates changes in parent values
+    \brief Animates changes in parent values.
 
     ParentAnimation is used to animate a parent change for an \l Item.
 
@@ -211,7 +211,7 @@ struct QQuickParentAnimationData : public QAbstractAnimationAction
     //### reverse should probably apply on a per-action basis
     bool reverse;
     QList<QQuickParentChange *> pc;
-    void doAction() Q_DECL_OVERRIDE
+    void doAction() override
     {
         for (int ii = 0; ii < actions.count(); ++ii) {
             const QQuickStateAction &action = actions.at(ii);
@@ -230,8 +230,8 @@ QAbstractAnimationJob* QQuickParentAnimation::transition(QQuickStateActions &act
 {
     Q_D(QQuickParentAnimation);
 
-    QQuickParentAnimationData *data = new QQuickParentAnimationData;
-    QQuickParentAnimationData *viaData = new QQuickParentAnimationData;
+    std::unique_ptr<QQuickParentAnimationData> data(new QQuickParentAnimationData);
+    std::unique_ptr<QQuickParentAnimationData> viaData(new QQuickParentAnimationData);
 
     bool hasExplicit = false;
     if (d->target && d->newParent) {
@@ -327,7 +327,7 @@ QAbstractAnimationJob* QQuickParentAnimation::transition(QQuickStateActions &act
                     }
 
                     if (scale != 0)
-                        rotation = qAtan2(transform.m12()/scale, transform.m11()/scale) * 180/M_PI;
+                        rotation = qRadiansToDegrees(qAtan2(transform.m12() / scale, transform.m11() / scale));
                     else {
                         qmlWarning(this) << QQuickParentAnimation::tr("Unable to preserve appearance under scale of 0");
                         ok = false;
@@ -371,14 +371,14 @@ QAbstractAnimationJob* QQuickParentAnimation::transition(QQuickStateActions &act
 
     if (data->actions.count()) {
         QSequentialAnimationGroupJob *topLevelGroup = new QSequentialAnimationGroupJob;
-        QActionAnimation *viaAction = d->via ? new QActionAnimation : 0;
+        QActionAnimation *viaAction = d->via ? new QActionAnimation : nullptr;
         QActionAnimation *targetAction = new QActionAnimation;
         //we'll assume the common case by far is to have children, and always create ag
         QParallelAnimationGroupJob *ag = new QParallelAnimationGroupJob;
 
         if (d->via)
-            viaAction->setAnimAction(viaData);
-        targetAction->setAnimAction(data);
+            viaAction->setAnimAction(viaData.release());
+        targetAction->setAnimAction(data.release());
 
         //take care of any child animations
         bool valid = d->defaultProperty.isValid();
@@ -405,11 +405,8 @@ QAbstractAnimationJob* QQuickParentAnimation::transition(QQuickStateActions &act
             topLevelGroup->appendAnimation(d->via ? viaAction : targetAction);
         }
         return initInstance(topLevelGroup);
-    } else {
-        delete data;
-        delete viaData;
     }
-    return 0;
+    return nullptr;
 }
 
 /*!
@@ -418,7 +415,7 @@ QAbstractAnimationJob* QQuickParentAnimation::transition(QQuickStateActions &act
     \inqmlmodule QtQuick
     \ingroup qtquick-animation-properties
     \inherits Animation
-    \brief Animates changes in anchor values
+    \brief Animates changes in anchor values.
 
     AnchorAnimation is used to animate an anchor change.
 
@@ -456,7 +453,7 @@ QQuickAnchorAnimation::~QQuickAnchorAnimation()
 QQmlListProperty<QQuickItem> QQuickAnchorAnimation::targets()
 {
     Q_D(QQuickAnchorAnimation);
-    return QQmlListProperty<QQuickItem>(this, d->targets);
+    return QQmlListProperty<QQuickItem>(this, &(d->targets));
 }
 
 /*!
@@ -532,8 +529,8 @@ QAbstractAnimationJob* QQuickAnchorAnimation::transition(QQuickStateActions &act
     data->interpolatorType = QMetaType::QReal;
     data->interpolator = d->interpolator;
     data->reverse = direction == Backward ? true : false;
-    data->fromSourced = false;
-    data->fromDefined = false;
+    data->fromIsSourced = false;
+    data->fromIsDefined = false;
 
     for (int ii = 0; ii < actions.count(); ++ii) {
         QQuickStateAction &action = actions[ii];
@@ -546,7 +543,7 @@ QAbstractAnimationJob* QQuickAnchorAnimation::transition(QQuickStateActions &act
     QQuickBulkValueAnimator *animator = new QQuickBulkValueAnimator;
     if (data->actions.count()) {
         animator->setAnimValue(data);
-        animator->setFromSourcedValue(&data->fromSourced);
+        animator->setFromIsSourcedValue(&data->fromIsSourced);
     } else {
         delete data;
     }
@@ -565,7 +562,7 @@ QAbstractAnimationJob* QQuickAnchorAnimation::transition(QQuickStateActions &act
     \ingroup qtquick-animation-properties
     \inherits Animation
     \since 5.0
-    \brief Animates an item along a path
+    \brief Animates an item along a path.
 
     When used in a transition, the path can be specified without start
     or end points, for example:
@@ -867,9 +864,9 @@ QAbstractAnimationJob* QQuickPathAnimation::transition(QQuickStateActions &actio
     data->exitInterval = d->duration ? qreal(d->exitDuration) / d->duration : qreal(0);
     data->endRotation = d->endRotation;
     data->reverse = direction == Backward ? true : false;
-    data->fromSourced = false;
-    data->fromDefined = (d->path && d->path->hasStartX() && d->path->hasStartY()) ? true : false;
-    data->toDefined = d->path ? true : false;
+    data->fromIsSourced = false;
+    data->fromIsDefined = (d->path && d->path->hasStartX() && d->path->hasStartY()) ? true : false;
+    data->toIsDefined = d->path ? true : false;
     int origModifiedSize = modified.count();
 
     for (int i = 0; i < actions.count(); ++i) {
@@ -888,8 +885,7 @@ QAbstractAnimationJob* QQuickPathAnimation::transition(QQuickStateActions &actio
         }
     }
 
-    if (target && d->path &&
-        (modified.count() > origModifiedSize || data->toDefined)) {
+    if (target && d->path && (modified.count() > origModifiedSize || data->toIsDefined)) {
         data->target = target;
         data->path = d->path;
         data->path->invalidateSequentialHistory();
@@ -900,13 +896,13 @@ QAbstractAnimationJob* QQuickPathAnimation::transition(QQuickStateActions &actio
 
             // treat interruptions specially, otherwise we end up with strange paths
             if ((data->reverse || prevData.reverse) && prevData.currentV > 0 && prevData.currentV < 1) {
-                if (!data->fromDefined && !data->toDefined && !prevData.painterPath.isEmpty()) {
+                if (!data->fromIsDefined && !data->toIsDefined && !prevData.painterPath.isEmpty()) {
                     QPointF pathPos = QQuickPath::sequentialPointAt(prevData.painterPath, prevData.pathLength, prevData.attributePoints, prevData.prevBez, prevData.currentV);
                     if (!prevData.anchorPoint.isNull())
                         pathPos -= prevData.anchorPoint;
                     if (pathPos == data->target->position()) {   //only treat as interruption if we interrupted ourself
                         data->painterPath = prevData.painterPath;
-                        data->toDefined = data->fromDefined = data->fromSourced = true;
+                        data->toIsDefined = data->fromIsDefined = data->fromIsSourced = true;
                         data->prevBez.isValid = false;
                         data->interruptStart = prevData.currentV;
                         data->startRotation = prevData.startRotation;
@@ -916,18 +912,18 @@ QAbstractAnimationJob* QQuickPathAnimation::transition(QQuickStateActions &actio
                 }
             }
         }
-        pa->setFromSourcedValue(&data->fromSourced);
+        pa->setFromIsSourcedValue(&data->fromIsSourced);
         pa->setAnimValue(data);
         pa->setDuration(d->duration);
         pa->setEasingCurve(d->easingCurve);
         return initInstance(pa);
     } else {
-        pa->setFromSourcedValue(0);
-        pa->setAnimValue(0);
+        pa->setFromIsSourcedValue(nullptr);
+        pa->setAnimValue(nullptr);
         delete pa;
         delete data;
     }
-    return 0;
+    return nullptr;
 }
 
 void QQuickPathAnimationUpdater::setValue(qreal v)
@@ -942,7 +938,7 @@ void QQuickPathAnimationUpdater::setValue(qreal v)
     }
     currentV = v;
     bool atStart = ((reverse && v == 1.0) || (!reverse && v == 0.0));
-    if (!fromSourced && (!fromDefined || !toDefined)) {
+    if (!fromIsSourced && (!fromIsDefined || !toIsDefined)) {
         qreal startX = reverse ? toX + anchorPoint.x() : target->x() + anchorPoint.x();
         qreal startY = reverse ? toY + anchorPoint.y() : target->y() + anchorPoint.y();
         qreal endX = reverse ? target->x() + anchorPoint.x() : toX + anchorPoint.x();
@@ -950,12 +946,12 @@ void QQuickPathAnimationUpdater::setValue(qreal v)
 
         prevBez.isValid = false;
         painterPath = path->createPath(QPointF(startX, startY), QPointF(endX, endY), QStringList(), pathLength, attributePoints);
-        fromSourced = true;
+        fromIsSourced = true;
     }
 
     qreal angle;
     bool fixed = orientation == QQuickPathAnimation::Fixed;
-    QPointF currentPos = !painterPath.isEmpty() ? path->sequentialPointAt(painterPath, pathLength, attributePoints, prevBez, v, fixed ? 0 : &angle) : path->sequentialPointAt(v, fixed ? 0 : &angle);
+    QPointF currentPos = !painterPath.isEmpty() ? path->sequentialPointAt(painterPath, pathLength, attributePoints, prevBez, v, fixed ? nullptr : &angle) : path->sequentialPointAt(v, fixed ? nullptr : &angle);
 
     //adjust position according to anchor point
     if (!anchorPoint.isNull()) {
